@@ -252,9 +252,17 @@ def get_client(progress=True):
             'https': '{}:{}'.format(cfg.proxy_host, cfg.proxy_port)
         }
     if progress:
-        client = Client(cfg.url, progress=cfg.progress_meter, progress_class=cfg.progress_class, oc_path_format=True, proxies=proxies)
+        client = Client(cfg.url,
+                        progress=cfg.progress_meter,
+                        progress_class=cfg.progress_class,
+                        oc_path_format=True,
+                        proxies=proxies,
+                        put_max_retry=cfg.put_max_retry)
     else:
-        client = Client(cfg.url, oc_path_format=True, proxies=proxies)
+        client = Client(cfg.url,
+                        oc_path_format=True,
+                        proxies=proxies,
+                        put_max_retry=cfg.put_max_retry)
     client.login(cfg.user_id, cfg.password)
     return client
 
@@ -772,6 +780,7 @@ def cmd():
     optparser.add_option(      "--password", dest="password", help="Owncloud user password")
     optparser.add_option(      "--url", dest="url", help="Owncloud url")
     optparser.add_option(      "--depth", dest="depth", help="The limit depth while traversing directory for [ls] command.", metavar="NUM")
+    optparser.add_option(      "--put-max-retry", dest="put_max_retry", help="The max retries when a file upload failed.", metavar="NUM")
     optparser.add_option(      "--list-md5", dest="list_md5", action="store_true", help="Include MD5 sums in dir listings (only for 'ls' command).")
     optparser.add_option("-l", "--long-listing", dest="long_listing", action="store_true", help="Produce long listing [ls]")
     optparser.add_option("-H", "--human-readable-sizes", dest="human_readable_sizes", action="store_true", help="Print sizes in human readable form (eg 1kB instead of 1024).")
